"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.jsonDeserializer = void 0;
var tslib_1 = require("tslib");
var RequestBodyNotJsonError_1 = require("./customErrors/RequestBodyNotJsonError");
exports.jsonDeserializer = function () { return function (handler) { return function (event, context) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
    var bodyObject;
    return tslib_1.__generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                bodyObject = deserializeBody(event);
                return [4 /*yield*/, handler(tslib_1.__assign(tslib_1.__assign({}, event), { bodyObject: bodyObject }), context)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); }; }; };
var deserializeBody = function (event) {
    var body = event.body, isBase64Encoded = event.isBase64Encoded;
    if (!body || !isJsonMimeType(event)) {
        return null;
    }
    var data = isBase64Encoded ? Buffer.from(body, "base64").toString() : body;
    try {
        return JSON.parse(data);
    }
    catch (error) {
        throw new RequestBodyNotJsonError_1.RequestBodyNotJsonError("Content-Type header specified JSON but the body is not valid JSON!", body, error);
    }
};
var isJsonMimeType = function (event) {
    var _a, _b;
    var headers = event.headers;
    var contentTypeHeader = (_a = headers === null || headers === void 0 ? void 0 : headers["Content-Type"]) !== null && _a !== void 0 ? _a : headers === null || headers === void 0 ? void 0 : headers["content-type"];
    if (!contentTypeHeader) {
        return false;
    }
    var mimeParts = contentTypeHeader.split("/");
    if (mimeParts.length != 2) {
        return false;
    }
    var lastSubtypePart = (_b = mimeParts[1].toLowerCase().split("+").pop()) === null || _b === void 0 ? void 0 : _b.trim();
    return lastSubtypePart === "json" || lastSubtypePart === "json;";
};
//# sourceMappingURL=JsonDeserializer.js.map